@@ -1,4 +1,4 @@
-package WebDriver::Tiny 0.005;
+package WebDriver::Tiny 0.006;
 
 use 5.020;
 use feature 'postderef';
@@ -104,13 +104,11 @@ sub new {
 
 sub capabilities { $_[0][3] }
 
-sub page_ids { $_[0]->_req( GET => '/window_handles' )->{value} }
-sub source   { $_[0]->_req( GET => '/source'         )->{value} }
-sub title    { $_[0]->_req( GET => '/title'          )->{value} }
-sub url      { $_[0]->_req( GET => '/url'            )->{value} }
+sub source { $_[0]->_req( GET => '/source' )->{value} }
+sub title  { $_[0]->_req( GET => '/title'  )->{value} }
+sub url    { $_[0]->_req( GET => '/url'    )->{value} }
 
 sub back       { $_[0]->_req( POST   => '/back'    ); $_[0] }
-sub close_page { $_[0]->_req( DELETE => '/window'  ); $_[0] }
 sub forward    { $_[0]->_req( POST   => '/forward' ); $_[0] }
 sub refresh    { $_[0]->_req( POST   => '/refresh' ); $_[0] }
 
@@ -226,20 +224,30 @@ sub find {
     my $must_be_visible
         = $method eq 'css selector' && $selector =~ s/:visible$//;
 
+    # FIXME
+    my $drv = ref $self eq 'WebDriver::Tiny::Elements' ? $self->[0] : $self;
+
     my @ids;
 
     for ( 0 .. ( $args{tries} // 5 ) ) {
         my $reply = $self->_req(
             POST => '/elements',
-            { using => $method, value => $selector },
+            { using => $method, value => "$selector" },
         );
 
-        @ids = map $_->{ELEMENT}, $reply->{value}->@*;
+        my $type = ref $reply->{value};
+        if ($type eq 'ARRAY') {
+            @ids = map $_->{ELEMENT}, $reply->{value}->@*;
+        }
+        elsif ($type eq 'HASH') {
+            Carp::croak ref $self, qq/->find failed: $reply->{value}{message}/;
+        }
+        else {
+            Carp::croak ref $self, qq/->find failed: $reply->{value}/;
+        }
 
-        # FIXME This'll break when called on elems->find(), this always need
-        # to be $drv NOT $self.
         @ids = grep {
-            $self->_req( GET => "/element/$_/displayed" )->{value}
+            $drv->_req( GET => "/element/$_/displayed" )->{value}
         } @ids if $must_be_visible;
 
         last if @ids;
@@ -250,11 +258,8 @@ sub find {
     Carp::croak ref $self, qq/->find failed for $method = "$_[1]"/
         if !@ids && !exists $args{dies} && !$args{dies};
 
-    # FIXME
-    $self = $self->[0] if ref $self eq 'WebDriver::Tiny::Elements';
-
-    wantarray ? map { bless [ $self, $_ ], 'WebDriver::Tiny::Elements' } @ids
-              : bless [ $self, @ids ], 'WebDriver::Tiny::Elements';
+    wantarray ? map { bless [ $drv, $_ ], 'WebDriver::Tiny::Elements' } @ids
+              : bless [ $drv, @ids ], 'WebDriver::Tiny::Elements';
 }
 
 my $js = sub {
@@ -304,16 +309,14 @@ sub screenshot {
     $data;
 }
 
-sub switch_page {
-    my ( $self, $id ) = @_;
-
-    $self->_req( POST => '/window', { name => $id } );
-
-    $self;
-}
-
 sub user_agent { $js->( '/execute', $_[0], 'return window.navigator.userAgent') }
 
+sub window  { $_[0]->_req( GET => '/window'         )->{value} }
+sub windows { $_[0]->_req( GET => '/window_handles' )->{value} }
+
+sub window_close      { $_[0]->_req( DELETE => '/window'            ); $_[0] }
+sub window_fullscreen { $_[0]->_req( POST   => '/window/fullscreen' ); $_[0] }
+
 sub window_maximize {
     $_[0]->_req( POST => '/window/' . ( $_[1] // 'current' ) . '/maximize' );
 
@@ -348,13 +351,21 @@ sub window_size {
     $self;
 }
 
+sub window_switch {
+    my ( $self, $handle ) = @_;
+
+    $self->_req( POST => '/window', { name => $handle } );
+
+    $self;
+}
+
 sub _req {
     my ( $self, $method, $path, $args ) = @_;
 
     my $reply = $self->[0]->request(
         $method,
         $self->[1] . $path,
-        $args ? { content => JSON::PP::encode_json $args } : (),
+        { content => JSON::PP::encode_json( $args // {} ) },
     );
 
     unless ( $reply->{success} ) {
@@ -364,7 +375,7 @@ sub _req {
             utf8::encode my $msg
                 = JSON::PP::decode_json($reply->{content})->{value}{message};
 
-            JSON::PP::decode_json($msg)->{errorMessage}
+            JSON::PP::decode_json($msg)->{errorMessage};
         };
 
         Carp::croak ref $self, ' - ', $error // $reply->{content};
@@ -373,6 +384,6 @@ sub _req {
     JSON::PP::decode_json $reply->{content};
 }
 
-sub DESTROY { $_[0]->_req( DELETE => '' ) if $_[0][3] }
+sub DESTROY { $_[0]->_req( DELETE => '' ) if $_[0][3] && $_[0][0] }
 
 1;
